@@ -79,7 +79,7 @@ def reset_shell_and_homedir (username, temp_homedir):
     usermod.set_homedir (username, "")
 
     dprint ("Deleting temporary homedir '%s'", temp_homedir)
-    shutil.rmtree (temp_homedir)
+    shutil.rmtree (temp_homedir, True)
         
     dprint ("Resetting shell for '%s' to '%s'", username, NOLOGIN_SHELL)
     usermod.set_shell (username, NOLOGIN_SHELL)
@@ -92,61 +92,24 @@ def clobber_user_processes (username):
     # FIXME: my, what a big hammer you have!
     argv = CLOBBER_USER_PROCESSES_ARGV + [ pw.pw_name ]
     dprint ("Clobbering existing processes running as user '%s': %s", pw.pw_name, argv)
-    util.uninterruptible_spawnv (os.P_WAIT, argv[0], argv)
+    subprocess.call (argv)
 
 def find_free_display ():
     def is_display_free (display_number):
-        # First make sure we get CONNREFUSED connecting
-        # to port 6000 + display_number
-        refused = False
-        sock = socket.socket (socket.AF_INET, socket.SOCK_STREAM)
         try:
-            sock.connect (("127.0.0.1", 6000 + display_number))
-        except socket.error, (err, errstr):
-            if err == errno.ECONNREFUSED:
-                refused = True
-        
-        sock.close ()
-        if not refused:
+            d = gtk.gdk.Display (":%d.0" % display_number)
+            d.close ()
             return False
-
-        # Now make sure either that the lock file doesn't exist or
-        # that the server specified in the lock file isn't running
-        lock_file = "/tmp/.X%d-lock" % display_number
-        if os.path.exists (lock_file):
-            f = file (lock_file, "r")
-            try:
-                pid = int (f.read ())
-            except ValueError:
-                return False
-
-            process_exists = True
-            try:
-                os.kill (pid, 0)
-            except os.error, (err, errstr):
-                if err == errno.ESRCH:
-                    process_exists = False
-            if process_exists:
-                return False
-
-            os.remove (lock_file)
-            
-        socket_file = "/tmp/.X11-unix/X%d" % display_number
-        if os.path.exists (socket_file):
-            os.remove (socket_file)
-
-        return True
+        except RuntimeError, e:
+            return True
 
     display_number = 1
     while display_number < 100:
         if is_display_free (display_number):
-            break
+            return display_number
         display_number += 1
         
-    if display_number == 100:
-        raise ProtoSessionError, _("Unable to find a free X display")
-
-    return display_number
+    raise ProtoSessionError, _("Unable to find a free X display")
         
 #
 # Everything beyond here gets run from sabayon-session
@@ -175,9 +138,9 @@ class ProtoSession (gobject.GObject):
         self.usr1_pipe_r = 0
         self.usr1_pipe_w = 0
         
-        self.xnest_pid = 0
-        self.xnest_child_watch = 0
-        self.xnest_xauth_file = None
+        self.xephyr_pid = 0
+        self.xephyr_child_watch = 0
+        self.xephyr_xauth_file = None
         
         self.session_pid = 0
         self.session_child_watch = 0
@@ -189,14 +152,14 @@ class ProtoSession (gobject.GObject):
 
         self.pw = pwd.getpwuid (os.getuid ())
         
-    def __kill_xnest (self):
-        if self.xnest_child_watch:
-            gobject.source_remove (self.xnest_child_watch)
-            self.xnest_child_watch = 0
+    def __kill_xephyr (self):
+        if self.xephyr_child_watch:
+            gobject.source_remove (self.xephyr_child_watch)
+            self.xephyr_child_watch = 0
         
-        if self.xnest_pid:
-            safe_kill (self.xnest_pid, signal.SIGTERM)
-            self.xnest_pid = 0
+        if self.xephyr_pid:
+            safe_kill (self.xephyr_pid, signal.SIGTERM)
+            self.xephyr_pid = 0
 
     def __kill_session (self):
         if self.session_child_watch:
@@ -221,8 +184,8 @@ class ProtoSession (gobject.GObject):
             self.admin_tool_pid = 0
 
     def __del__ (self):
-        if self.xnest_xauth_file:
-            os.remove (self.xnest_xauth_file)
+        if self.xephyr_xauth_file:
+            os.remove (self.xephyr_xauth_file)
         if self.session_xauth_file:
             os.remove (self.session_xauth_file)
         if self.usr1_pipe_r:
@@ -240,11 +203,11 @@ class ProtoSession (gobject.GObject):
         self.got_usr1_signal = True
         os.write (self.usr1_pipe_w, "Y")
 
-    def __xnest_child_watch_handler (self, pid, status):
-        dprint ("Xnest died")
+    def __xephyr_child_watch_handler (self, pid, status):
+        dprint ("Xephyr died")
         
-        self.xnest_pid = 0
-        self.xnest_child_watch = 0
+        self.xephyr_pid = 0
+        self.xephyr_child_watch = 0
 
         self.emit ("finished");
         
@@ -268,7 +231,7 @@ class ProtoSession (gobject.GObject):
 
     # Write out a temporary Xauthority file which contains the same magic
     # cookie as the parent display so that we can pass that using -auth
-    # to Xnest.
+    # to Xephyr.
     #
     # Xauthority is a binary file format:
     #
@@ -350,22 +313,21 @@ class ProtoSession (gobject.GObject):
     # runing the mainloop we re-enter, then we'll install another
     # SIGUSR1 handler and everything will break
     #
-    def __start_xnest (self, parent_window):
-        dprint ("Starting Xnest %s" % self.display_name)
+    def __start_xephyr (self, parent_window):
+        dprint ("Starting Xephyr %s" % self.display_name)
 
-        self.xnest_xauth_file = self.__write_temp_xauth_file (True)
+        self.xephyr_xauth_file = self.__write_temp_xauth_file (True)
 
         (self.usr1_pipe_r, self.usr1_pipe_w) = os.pipe ()
         self.got_usr1_signal = False
         signal.signal (signal.SIGUSR1, self.__sigusr1_handler)
 
-        self.xnest_pid = os.fork ()
-        if self.xnest_pid == 0: # Child process
+        self.xephyr_pid = os.fork ()
+        if self.xephyr_pid == 0: # Child process
             signal.signal (signal.SIGUSR1, signal.SIG_IGN)
 
-            argv = XNEST_ARGV + \
-                   [ "-auth", self.xnest_xauth_file ] + \
-                   [ "-name", "sabayon" ]
+            argv = XEPHYR_ARGV + \
+                   [ "-auth", self.xephyr_xauth_file ]
             if parent_window:
                 argv += [ "-parent", parent_window ]
             argv += [ self.display_name ]
@@ -375,20 +337,20 @@ class ProtoSession (gobject.GObject):
             os.execv (argv[0], argv)
 
             # Shouldn't ever reach here
-            sys.stderr.write ("Failed to launch Xnest")
+            sys.stderr.write ("Failed to launch Xephyr")
             os._exit (1)
 
         self.main_loop = gobject.MainLoop ()
 
-        self.xnest_child_watch = gobject.child_watch_add (self.xnest_pid,
-                                                          self.__xnest_child_watch_handler)
+        self.xephyr_child_watch = gobject.child_watch_add (self.xephyr_pid,
+                                                           self.__xephyr_child_watch_handler)
         io_watch = gobject.io_add_watch (self.usr1_pipe_r,
                                          gobject.IO_IN | gobject.IO_PRI,
                                          self.__usr1_pipe_watch_handler)
-        timeout = gobject.timeout_add (XNEST_USR1_TIMEOUT * 1000,
-                                       self.__usr1_timeout_handler)
+        timeout = gobject.timeout_add_seconds (XEPHYR_USR1_TIMEOUT,
+                                               self.__usr1_timeout_handler)
 
-        dprint ("Waiting on child process (%d)" % self.xnest_pid)
+        dprint ("Waiting on child process (%d)" % self.xephyr_pid)
 
         self.main_loop.run ()
         self.main_loop = None
@@ -404,16 +366,16 @@ class ProtoSession (gobject.GObject):
         self.usr1_pipe_w = 0
 
         if not self.got_usr1_signal:
-            if self.xnest_child_watch:
-                gobject.source_remove (self.xnest_child_watch)
-                self.xnest_child_watch = 0
+            if self.xephyr_child_watch:
+                gobject.source_remove (self.xephyr_child_watch)
+                self.xephyr_child_watch = 0
             
-            if self.xnest_pid:
-                safe_kill (self.xnest_pid, signal.SIGTERM)
-                self.xnest_pid = 0
-                raise SessionStartError, _("Failed to start Xnest: timed out waiting for USR1 signal")
+            if self.xephyr_pid:
+                safe_kill (self.xephyr_pid, signal.SIGTERM)
+                self.xephyr_pid = 0
+                raise SessionStartError, _("Failed to start Xephyr: timed out waiting for USR1 signal")
             else:
-                raise SessionStartError, _("Failed to start Xnest: died during startup")
+                raise SessionStartError, _("Failed to start Xephyr: died during startup")
 
     def __session_child_watch_handler (self, pid, status):
         dprint ("Session died")
@@ -452,6 +414,12 @@ class ProtoSession (gobject.GObject):
             # Disable Xscreensaver locking
             new_environ["RUNNING_UNDER_GDM"] = "yes"
 
+            # Don't let the child session's gvfs use FUSE, so old
+            # gvfs-fuse-daemons that crash won't make FUSE turn
+            # /tmp/blahblah/.gvfs unreadable --- this screws up
+            # resetting and erasing the temporary home directory.
+            new_environ["GVFS_DISABLE_FUSE"] = "yes"
+
             dprint ("Child process env: %s" % new_environ)
             
             # Start the session
@@ -474,7 +442,7 @@ class ProtoSession (gobject.GObject):
 
         try:
             pipe = subprocess.Popen (argv,
-                                     stderr = subprocess.PIPE,
+#                                     stderr = subprocess.PIPE,
                                      env = os.environ)
         except Exception, e:
             raise errors.FatalApplyErrorException (("Could not create the 'sabayon-apply' process: %s\n" +
@@ -485,7 +453,7 @@ class ProtoSession (gobject.GObject):
                                                     e.child_traceback))
 
         return_code = pipe.wait ()
-        stderr_str = pipe.stderr.read ()
+#        stderr_str = pipe.stderr.read ()
 
 #        print "<BEGIN SABAYON-APPLY STDERR>\n%s\n<END SABAYON-APPLY STDERR>" % stderr_str
 
@@ -494,31 +462,31 @@ class ProtoSession (gobject.GObject):
             pass
         elif return_code == util.EXIT_CODE_RECOVERABLE:
             mprint ("Finished running sabayon-apply with RECOVERABLE exit status")
-            mprint ("========== BEGIN SABAYON-APPLY LOG (RECOVERABLE) ==========\n"
-                    "%s\n"
-                    "========== END SABAYON-APPLY LOG (RECOVERABLE) ==========",
-                    stderr_str)
+#            mprint ("========== BEGIN SABAYON-APPLY LOG (RECOVERABLE) ==========\n"
+#                    "%s\n"
+#                    "========== END SABAYON-APPLY LOG (RECOVERABLE) ==========",
+#                    stderr_str)
             raise errors.RecoverableApplyErrorException (_("There was a recoverable error while applying "
                                                            "the user profile from file '%s'.") % self.profile_file)
         else:
             # return_code == util.EXIT_CODE_FATAL or something else
             mprint ("Finished running sabayon-apply with FATAL exit status")
-            mprint ("========== BEGIN SABAYON-APPLY LOG (FATAL) ==========\n"
-                    "%s\n"
-                    "========== END SABAYON-APPLY LOG (FATAL) ==========",
-                    stderr_str)
+#            mprint ("========== BEGIN SABAYON-APPLY LOG (FATAL) ==========\n"
+#                    "%s\n"
+#                    "========== END SABAYON-APPLY LOG (FATAL) ==========",
+#                    stderr_str)
             raise errors.FatalApplyErrorException (_("There was a fatal error while applying the "
                                                      "user profile from '%s'.") % self.profile_file)
 
     def start (self, parent_window):
         # Get an X server going
-        self.__start_xnest (parent_window)
+        self.__start_xephyr (parent_window)
 
         # Start the session
         self.__start_session ()
         
     def force_quit (self):
         self.__kill_session ()
-        self.__kill_xnest ()
+        self.__kill_xephyr ()
 
 gobject.type_register (ProtoSession)
